/********************************
 *
 * NAME:
 * ----
 * randbEmitter/main.c
 *
 * AUTHORS:
 * -------
 * Alvaro Gutierrez -- aguti@etsit.upm.es
 * Alexandre Campo  -- acampo@ulb.ac.be
 *
 * REVISION HISTORY:
 *-----------------
 * 12/12/2008
 *
 * ADDITIONAL NOTES:
 * ----------------
 * A test for the e-randb board.
 * The code just broadcast data from 0-65535 
 */




#include <p30f6014a.h>
#include <stdio.h>
#include <string.h>
#include <math.h>
#include <btcom.h>
#include <e_randb.h>
#include <e_prox.h>
#include <e_uart_char.h>
#include <e_init_port.h>

int main() {

	/* System Initialization */
	e_init_port();
	/* Init UART1 for bluetooth */
	e_init_uart1();
	/* Init E-RANDB board */
	e_init_randb(I2C);
	
	/* Wait for a command comming from bluetooth IRCOMTEST on pc directory*/
	/* Important issue when we are transmitting data and don't want
	 * the bluetooth stack stuck for programing mode */
	btcomWaitForCommand('s');

	/* Range is tunable by software. 
	 * 0 -> Full Range (1m. approx depending on light conditions )
	 * 255 --> No Range (0cm. approx, depending on light conditions */
	e_randb_set_range(0);

	/* At some point we tought that the board could just take
	 * data en leave the calculations for the robot.
	 * At the moment, it is better to allow the board to do the calculations */
	e_randb_set_calculation(ON_BOARD);

	/* Store light conditions to use them as offset for the calculation 
	 * of the range and bearing */
	e_randb_store_light_conditions();

	/* Print on the bluetooth */
	char tmp2[50];
	sprintf(tmp2,"I2C EMITTER\n");
	btcomSendString(tmp2);

	/* The counter for sending */
	unsigned int data = 0;

	while(1)
	{
		/* Send the data in one sensor */
		e_randb_store_data(0,data);
		e_randb_send_data();

		/* Increase data */
		data++;
		
		/* Data to be sent must be lower than 16 bits */
		if(data==65535) data=0;
	}
	return 0;
}
