#include <p30f6014a.h>
#include <stdio.h>
#include <string.h>
#include <math.h>

#include <e_uart_char.h>
#include <e_init_port.h>
#include <e_led.h>
#include <e_randb.h>
#include <e_agenda.h>
#include <e_prox.h>

#include <btcom.h>

#define M_PI 3.141593
int main() {

	/* System Initialization */
	e_init_port();
	/* Init UART1 for bluetooth */
	e_init_uart1();
	/* Init E-RANDB board */
	e_init_randb(UART);

	/* Wait for a command comming from bluetooth IRCOMTEST on pc directory*/
	/* Important issue when we are transmitting data and don't want
	 * the bluetooth stack stuck for programing mode */
	btcomWaitForCommand('s');

	/* Range is tunable by software. 
	 * 0 -> Full Range (1m. approx depending on light conditions )
	 * 255 --> No Range (0cm. approx, depending on light conditions */
	e_randb_set_range(150);

	/* At some point we tought that the board could just take
	 * data en leave the calculations for the robot.
	 * At the moment, it is better to allow the board to do the calculations */
	e_randb_set_calculation(ON_BOARD);

	/* Store light conditions to use them as offset for the calculation 
	 * of the range and bearing */
	e_randb_store_light_conditions();

	/* Print on the bluetooth */
	char tmp[20];
	sprintf(tmp,"UART RECEIVER\n");
	btcomSendString(tmp);

	finalDataRegister data;
	while(1)
	{
		if (e_randb_get_data_uart(&data))
		{
			sprintf(tmp,"%d %d %d\n",data.data, (int) (data.bearing * 180.0 / M_PI), data.range);
			btcomSendString(tmp);
		}
	}
	return 0;
}
