#include <p30f6014a.h>
#include <stdio.h>
#include <string.h>
#include <math.h>

#include <e_uart_char.h>
#include <e_init_port.h>
#include <e_led.h>
#include <e_randb.h>
#include <e_agenda.h>
#include <e_epuck_ports.h>

#include <btcom.h>

#define SAMPLING_TIME 10 /* milliseconds*/

long int m_uTime;

void initTimer ( void )
{
	T3CON = 0;                    // 
	T3CONbits.TCKPS = 3;          // prescsaler 
	TMR3 = 0;                     // clear timer 3
	PR3 = (SAMPLING_TIME * MILLISEC)/256.0;
	IFS0bits.T3IF = 0;            // clear interrupt flag
	IEC0bits.T3IE = 1;            // set interrupt enable bit
	IPC1bits.T3IP = 6;            // timer3 priority. Priority set to 6
	T3CONbits.TON = 1;            // start Timer3

	m_uTime = 0;
}

void _ISRFAST _T3Interrupt(void)
{
	/* clear interrupt flag */
	IFS0bits.T3IF = 0;
	
	m_uTime++;
}
int main() {

	/* System Initialization */
	e_init_port();
	/* Init UART1 for bluetooth */
	e_init_uart1();
	/* Init E-RANDB board */
	e_init_randb(UART);
	
	/* Wait for a command comming from bluetooth */
	/* Important issue when we are transmitting data and don't want
	 * the bluetooth stack stuck for programing mode */
	btcomWaitForCommand('s');

	/* Range is tunable by software. 
	 * 0 -> Full Range (1m. approx depending on light conditions )
	 * 255 --> No Range (0cm. approx, depending on light conditions */
	e_randb_set_range(150);

	/* At some point we tought that the board could just take
	 * data en leave the calculations for the robot.
	 * At the moment, it is better to allow the board to do the calculations */
	/*e_randb_set_calculation(ON_ROBOT);*/
	e_randb_set_calculation(ON_BOARD);

	/* Store light conditions to use them as offset for the calculation 
	 * of the range and bearing */
	e_randb_store_light_conditions();

	/*unsigned int value;*/
	char tmp[50];
	sprintf(tmp,"UART Multiple RECEIVER\n");
	btcomSendString(tmp);

	initTimer();
	
	int counter=0;
	
	finalDataRegister data;
	while(1)
	{
		
		if (e_randb_get_data_uart(&data))
		{
			sprintf(tmp,"%2f %ld\n",data.bearing, m_uTime);
			btcomSendString(tmp);
			counter++;
		}
	}
	return 0;
}
